@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	main.c
  *----------------------------------------------------------------------*
- * $Id: main.c,v 1.66.2.11 2000/06/04 06:47:32 gcw Exp $
+ * $Id: main.c,v 1.66.2.12 2000/10/28 05:44:28 gcw Exp $
  *
  * All portions of code are copyright by their respective author/s.
  * Copyright (C) 1992      John Bovey, University of Canterbury
@@ -1141,8 +1141,6 @@ init_resources(int argc, const char * const *argv)
 	rs[i] = NULL;
 
     rs[Rs_name] = my_basename(argv[0]);
-    if (cmd_argv != NULL && cmd_argv[0] != NULL)
-	rs[Rs_iconName] = rs[Rs_title] = my_basename(cmd_argv[0]);
 /*
  * Open display, get options/resources and create the window
  */
@@ -1176,10 +1174,17 @@ init_resources(int argc, const char * const *argv)
 /*
  * set any defaults not already set
  */
-    if (!rs[Rs_title])
-	rs[Rs_title] = rs[Rs_name];
-    if (!rs[Rs_iconName])
-	rs[Rs_iconName] = rs[Rs_title];
+    if (cmd_argv && cmd_argv[0]) {
+	if (!rs[Rs_title])
+	    rs[Rs_title] = my_basename(cmd_argv[0]);
+	if (!rs[Rs_iconName])
+	    rs[Rs_iconName] = rs[Rs_title];
+    } else {
+	if (!rs[Rs_title])
+	    rs[Rs_title] = rs[Rs_name];
+	if (!rs[Rs_iconName])
+	    rs[Rs_iconName] = rs[Rs_name];
+    }
     if (!rs[Rs_saveLines] || (TermWin.saveLines = atoi(rs[Rs_saveLines])) < 0)
 	TermWin.saveLines = SAVELINES;
 
