@@ -1,7 +1,7 @@
 /*--------------------------------*-C-*---------------------------------*
  * File:	menubar.c
  *----------------------------------------------------------------------*
- * $Id: menubar.c,v 1.24 1998/11/16 17:26:44 mason Exp $
+ * $Id: menubar.c,v 1.27 1999/01/23 14:26:36 mason Exp $
  *
  * Copyright (C) 1997,1998  mj olesen <olesen@me.QueensU.CA>
  *
@@ -76,8 +76,8 @@ menuitem_find(const menu_t *menu, const char *name)
 	if (item->entry.type == MenuSubMenu) {
 	    if (!strcmp(name, (item->entry.submenu.menu)->name))
 		break;
-	} else if ((isSeparator(name) && isSeparator(item->name)) ||
-		   !strcmp(name, item->name))
+	} else if ((isSeparator(name) && isSeparator(item->name))
+		   || !strcmp(name, item->name))
 	    break;
     }
     return item;
@@ -539,8 +539,8 @@ menu_find_base(menu_t **menu, char *path)
     } else {
     /* find this menu */
 	for (item = (*menu)->tail; item != NULL; item = item->prev) {
-	    if (item->entry.type == MenuSubMenu &&
-		!strcmp(path, (item->entry.submenu.menu)->name)) {
+	    if (item->entry.type == MenuSubMenu
+		&& !strcmp(path, (item->entry.submenu.menu)->name)) {
 		m = (item->entry.submenu.menu);
 		break;
 	    }
@@ -594,8 +594,8 @@ menu_delete(menu_t *menu)
 	    next->x -= len;
     } else {
 	for (item = parent->tail; item != NULL; item = item->prev) {
-	    if (item->entry.type == MenuSubMenu &&
-		item->entry.submenu.menu == menu) {
+	    if (item->entry.type == MenuSubMenu
+		&& item->entry.submenu.menu == menu) {
 		item->entry.submenu.menu = NULL;
 		menuitem_free(menu->parent, item);
 		break;
@@ -818,8 +818,8 @@ print_menu_ancestors(menu_t *menu)
 	menuitem_t     *item;
 
 	for (item = menu->parent->head; item != NULL; item = item->next) {
-	    if (item->entry.type == MenuSubMenu &&
-		item->entry.submenu.menu == menu) {
+	    if (item->entry.type == MenuSubMenu
+		&& item->entry.submenu.menu == menu) {
 		break;
 	    }
 	}
@@ -2072,8 +2072,8 @@ menu_select(XButtonEvent *ev)
     }
 /* determine the menu item corresponding to the Y index */
     y = SHADOW;
-    if (ev->x >= 0 &&
-	ev->x <= (ActiveMenu->w - SHADOW)) {
+    if (ev->x >= 0
+	&& ev->x <= (ActiveMenu->w - SHADOW)) {
 	for (item = ActiveMenu->head; item != NULL; item = item->next) {
 	    int             h = HEIGHT_TEXT + 2 * SHADOW;
 
@@ -2128,19 +2128,11 @@ menu_select(XButtonEvent *ev)
 		 * remove menu before sending keys to the application
 		 */
 		    {
-#ifdef __CYGWIN32__
 			struct timeval  tv;
 
 			tv.tv_sec = 0;
 			tv.tv_usec = MENU_DELAY_USEC;
 			select(0, NULL, NULL, NULL, &tv);
-#else
-			struct itimerval tv;
-
-			tv.it_value.tv_sec = 0;
-			tv.it_value.tv_usec = MENU_DELAY_USEC;
-			select(0, NULL, NULL, NULL, &tv.it_value);
-#endif
 		    }
 		    menu_hide_all();
 #ifndef DEBUG_MENU
@@ -2214,34 +2206,26 @@ menubar_select(XButtonEvent *ev)
 	    int             i;
 
 	    for (i = 0; i < NARROWS; i++) {
-		if (ev->x >= (Arrows_x + (Width2Pixel(4 * i + i)) / 4) &&
-		    ev->x < (Arrows_x + (Width2Pixel(4 * i + i + 4)) / 4)) {
+		if (ev->x >= (Arrows_x + (Width2Pixel(4 * i + i)) / 4)
+		    && ev->x < (Arrows_x + (Width2Pixel(4 * i + i + 4)) / 4)) {
 		    draw_Arrows(Arrows[i].name, -1);
 		/*
 		 * use select for timing
 		 */
 		    {
-#ifdef __CYGWIN32__
 			struct timeval  tv;
 
 			tv.tv_sec = 0;
 			tv.tv_usec = MENU_DELAY_USEC;
 			select(0, NULL, NULL, NULL, &tv);
-#else
-			struct itimerval tv;
-
-			tv.it_value.tv_sec = 0;
-			tv.it_value.tv_usec = MENU_DELAY_USEC;
-			select(0, NULL, NULL, NULL, &tv.it_value);
-#endif
 		    }
 		    draw_Arrows(Arrows[i].name, +1);
 #ifdef DEBUG_MENUARROWS
 		    fprintf(stderr, "'%c': ", Arrows[i].name);
 
-		    if (CurrentBar == NULL ||
-			(CurrentBar->arrows[i].type != MenuAction &&
-			 CurrentBar->arrows[i].type != MenuTerminalAction)) {
+		    if (CurrentBar == NULL
+			|| (CurrentBar->arrows[i].type != MenuAction
+			    && CurrentBar->arrows[i].type != MenuTerminalAction)) {
 			if (Arrows[i].str != NULL && Arrows[i].str[0])
 			    fprintf(stderr, "(default) \\033%s\n",
 				    &(Arrows[i].str[2]));
@@ -2249,10 +2233,10 @@ menubar_select(XButtonEvent *ev)
 			fprintf(stderr, "%s\n", CurrentBar->arrows[i].str);
 		    }
 #else				/* DEBUG_MENUARROWS */
-		    if (CurrentBar == NULL ||
-			action_dispatch(&(CurrentBar->arrows[i]))) {
-			if (Arrows[i].str != NULL &&
-			    Arrows[i].str[0] != 0)
+		    if (CurrentBar == NULL
+			|| action_dispatch(&(CurrentBar->arrows[i]))) {
+			if (Arrows[i].str != NULL
+			    && Arrows[i].str[0] != 0)
 			    tt_write((Arrows[i].str + 1),
 				     Arrows[i].str[0]);
 		    }
@@ -2298,7 +2282,7 @@ menubar_control(XButtonEvent *ev)
 	break;
 
     case MotionNotify:
-	while (XCheckTypedWindowEvent(Xdisplay, TermWin.parent,
+	while (XCheckTypedWindowEvent(Xdisplay, TermWin.parent[0],
 				      MotionNotify,
 				      (XEvent *) ev)) ;
 
@@ -2339,7 +2323,7 @@ create_menuBar(Cursor cursor)
 {
 #ifdef MENUBAR
 /* menuBar: size doesn't matter */
-    menuBar.win = XCreateSimpleWindow(Xdisplay, TermWin.parent,
+    menuBar.win = XCreateSimpleWindow(Xdisplay, TermWin.parent[0],
 				      0, 0,
 				      1, 1,
 				      0,
