@@ -1,5 +1,5 @@
 /*
- * $Id: screen.h,v 1.7 1998/11/16 17:52:20 mason Exp $
+ * $Id: screen.h,v 1.8 1998/11/25 16:34:13 mason Exp $
  */
 
 #ifndef _SCREEN_H		/* include once only */
@@ -8,9 +8,9 @@
 typedef unsigned char text_t;
 
 #if defined(MULTICHAR_SET)
-typedef R_u_int32_t	rend_t;
+#define rend_t		u_int32_t
 #else
-typedef R_u_int16_t	rend_t;
+#define rend_t		u_int16_t
 #endif
 
 /*
@@ -54,10 +54,10 @@ typedef R_u_int16_t	rend_t;
  */
 typedef struct {
     text_t        **text;	/* _all_ the text                            */
-    R_int16_t	   *tlen;	/* length of each text line                  */
+    int16_t	   *tlen;	/* length of each text line                  */
     rend_t        **rend;	/* rendition, uses RS_ flags                 */
     row_col_t       cur;	/* cursor position on the screen             */
-    R_int16_t       tscroll,	/* top of settable scroll region             */
+    int16_t         tscroll,	/* top of settable scroll region             */
                     bscroll,	/* bottom of settable scroll region          */
 		    charset;	/* character set number [0..3]               */
     unsigned int    flags;	/* see below                                 */
@@ -65,7 +65,7 @@ typedef struct {
 
 typedef struct {
     row_col_t	    cur;	/* cursor position                           */
-    R_int16_t	    charset;	/* character set number [0..3]               */
+    int16_t	    charset;	/* character set number [0..3]               */
     char            charset_char;
     rend_t          rstyle;	/* rendition style                           */
 } save_t;
@@ -114,7 +114,7 @@ EXTSCR text_t    **drawn_text;
 EXTSCR rend_t    **drawn_rend;
 EXTSCR text_t    **buf_text;
 EXTSCR rend_t    **buf_rend;
-EXTSCR R_int16_t  *buf_tlen;
+EXTSCR int16_t    *buf_tlen;
 EXTSCR char       *tabs;	/* a 1 for a location with a tab-stop */
 EXTSCR screen_t    screen;
 EXTSCR screen_t    swap;
